from __future__ import annotations

import argparse
import os


# https://stackoverflow.com/a/10551190/11109181
class EnvDefault(argparse.Action):
    def __init__(self, envvar, required=True, default=None, help=None, **kwargs):
        if envvar:
            if envvar in os.environ:
                default = os.environ[envvar]
        if required and default is not None:
            required = False

        if default is not None and help is not None:
            help += f" (default: {default})"

        if envvar and help is not None:
            help += f"\nCan also be specified through the {envvar} environment variable"
        super(EnvDefault, self).__init__(default=default, required=required, help=help,
                                         **kwargs)

    def __call__(self, parser, namespace, values, option_string=None):
        setattr(namespace, self.dest, values)
